Scrapple implementation classes — Scrapple documentation

### Navigation

- index
- modules |
- next |
- previous |
- Scrapple documentation »

# Scrapple implementation classes

There are two main categories of classes involved in the implementation of extractors on Scrapple :

- Command classes
- Selector classes

Command classes define the execution of the commands provided by Scrapple.

Selector classes define the implementation of the extraction through the selector expressions.

The following class diagram can be used to represent the relationship between the various classes.

Scrapple class diagram

### Navigation

- index
- modules |
- next |
- previous |
- Scrapple documentation »